@@ -152,7 +152,7 @@ def write_default_ansible_cfg(work_dir,
         sio_cfg = StringIO()
         sio_cfg.write(override_ansible_cfg)
         sio_cfg.seek(0)
-        config.readfp(sio_cfg)
+        config.read_file(sio_cfg)
         sio_cfg.close()
 
     with open(ansible_config_path, 'w') as configfile:
@@ -340,8 +340,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
         python_version = sys.version_info.major
         ansible_playbook_cmd = "ansible-playbook-{}".format(python_version)
 
-        if 0 < self.verbosity < 6:
-            verbosity_option = '-' + ('v' * self.verbosity)
+        if 1 < self.verbosity < 6:
+            verbosity_option = '-' + ('v' * (self.verbosity - 1))
             command = [ansible_playbook_cmd, verbosity_option,
                        self.playbook]
         else:
