@@ -59,7 +59,7 @@ class TestConfig(base.TestCase):
                             'service_metadata_settings',
                             'service_names',
                             'upgrade_batch_tasks', 'upgrade_tasks',
-                            'external_deploy_tasks']
+                            'external_deploy_steps_tasks']
 
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
@@ -74,6 +74,11 @@ class TestConfig(base.TestCase):
         mock_mkdir.assert_called()
         expected_calls = []
         for config in config_type_list:
+            if 'external' in config:
+                for step in range(constants.DEFAULT_STEPS_MAX):
+                    expected_calls += [call('/tmp/tht/%s_step%s.yaml' %
+                                       (config, step))]
+
             for role in fake_role:
                 if 'external' in config:
                     continue
@@ -180,7 +185,7 @@ class TestConfig(base.TestCase):
                                         % step)
                 playbook_tasks = self.config._write_tasks_per_step(
                     self.config.stack_outputs.get('RoleData')[role]
-                    ['upgrade_tasks'], role, filepath, step)
+                    ['upgrade_tasks'], filepath, step)
                 self.assertTrue(os.path.isfile(filepath))
                 self.assertEqual(expected_tasks[role][step], playbook_tasks)
 
@@ -1034,3 +1039,107 @@ class OvercloudConfigTest(base.TestCase):
                          'config-download-latest'))
         mock_os_unlink.assert_called_once_with(
             '/var/lib/mistral/config-download-latest')
+
+    @patch.object(ooo_config.Config, '_open_file')
+    def test_overcloud_config__write_tasks_per_step(self, mock_open_file):
+        heat = mock.MagicMock()
+        self.config = ooo_config.Config(heat)
+
+        # TODO: how can I share this tasks definition between to test
+        # as a fixture So that I do two several test cases instead of
+        # a big one.
+        tasks = [
+            {
+                "when": "step|int == 0",
+                "name": "Simple check"
+            },
+            {
+                "when": "(step|int == 0)",
+                "name": "Check within parenthesis"
+            },
+            {
+                "when": ["step|int == 0", "test1", False],
+                "name": "Check with list with boolean"
+            },
+            {
+                "when": ["test1", False, "step|int == 0"],
+                "name": "Check with list with boolean other order"
+            },
+            {
+                "when": "step|int == 0 or step|int == 3",
+                "name": "Check with boolean expression"
+            },
+            {
+                "when": "(step|int == 0 or step|int == 3) and other_cond",
+                "name": "Complex boolean expression"
+            },
+            {
+                "name": "Task with no conditional"
+            }
+        ]
+
+        # Everything should come back
+        tasks_per_step = self.config._write_tasks_per_step(
+            tasks,
+            'Compute/update_tasks_step0.yaml',
+            0
+        )
+
+        self.assertEqual(tasks, tasks_per_step)
+
+        # Using stict the tasks with no conditional will be dropped
+        tasks_per_step = self.config._write_tasks_per_step(
+            tasks,
+            'Compute/update_tasks_step0.yaml',
+            0,
+            strict=True,
+        )
+
+        expected_tasks = [task for task in tasks
+                          if task != {"name": "Task with no conditional"}]
+        self.assertEqual(expected_tasks,
+                         tasks_per_step)
+
+        # Some tasks will be filtered out for step 3.
+        tasks_per_step = self.config._write_tasks_per_step(
+            tasks,
+            'Compute/update_tasks_step3.yaml',
+            3
+        )
+
+        self.assertEqual(
+            [
+                {
+                    "when": "step|int == 0 or step|int == 3",
+                    "name": "Check with boolean expression"
+                },
+                {
+                    "when": "(step|int == 0 or step|int == 3) and other_cond",
+                    "name": "Complex boolean expression"
+                },
+                {
+                    "name": "Task with no conditional"
+                }
+            ],
+            tasks_per_step)
+
+        # Even more tasks will be filtered out for step 3 with strict.
+        tasks_per_step = self.config._write_tasks_per_step(
+            tasks,
+            'Compute/update_tasks_step3.yaml',
+            3,
+            strict=True,
+        )
+
+        self.assertEqual(
+            [
+                {
+                    "when": "step|int == 0 or step|int == 3",
+                    "name": "Check with boolean expression"
+                },
+                {
+                    "when": "(step|int == 0 or step|int == 3) and other_cond",
+                    "name": "Complex boolean expression"
+                },
+            ],
+            tasks_per_step)
